//Stata code-copyright , Economic Research Department, Nepal Rastra Bank
// Pls cite this code as reference before using in other academic work
//Author, Sushil Poudel, Dy. Director, Nepal Rastra Bank (Email: sushilpoudel@nrb.org.np, M: 9841510459) 
// Needs two data, FLI (containing Survey Data), local_det_gender (containg local level data on male and female population) of selected local level in survey

//Uncomment location and change it to your working directory, paste datasets in set directory before running this code

//cd "C:\Users\S00625\OneDrive\Documents\FLI"
clear
append using FLI
// Generate Knowledge Score (Exclde Division as per guidelines)
gen division=1 if q20==1
replace division=0 if division==.
label variable division "Division"

gen inf_pp=1 if q21==1
replace inf_pp=0 if inf_pp==.
label variable inf_pp "Impact of Inflation on Purchasing Power"

gen con_int=1 if q22==1
replace con_int=0 if con_int==.
label variable con_int "Concept of Interest "

gen simp_int=1 if q23==1
replace simp_int=0 if simp_int==.
label variable simp_int "Simple Interest Rate "

gen comp_int=1 if q24==1
replace comp_int=0 if comp_int==.
label variable comp_int "Compound Interest Rate"

gen risk_return=1 if q25==1
replace risk_return=0 if risk_return==.
label variable risk_return "Risk and Return"

gen impct_inf=1 if q26==1
replace impct_inf=0 if impct_inf==.
label variable impct_inf "Impact of Inflation"

gen risk_div=1 if q27==1
replace risk_div=0 if risk_div==.
label variable risk_div "Risk Diversification"

egen fknowledge=rowtotal(inf_pp con_int simp_int comp_int risk_return impct_inf risk_div)
label variable fknowledge "Financial Knowledge"

// Generate Behavior Score

//Budgeting
gen budget_self=1 if inlist(q17, 1, 2, 3, 4)
replace budget_self=0 if budget_self==.
egen budget_activity=rowtotal( q181 q182 q183 q184)
// Atleast 2 activity out of 4 budgeting activity
gen budgeting=1 if budget_self==1 & budget_activity>=2
replace budgeting=0 if budgeting==.
label variable budgeting "Prepare Budget"

//Active Saving
replace q191=0 if q191==.
replace q192=0 if q192==.
replace q193=0 if q193==.
replace q194=0 if q194==.
replace q195=0 if q195==.
replace q196=0 if q196==.
replace q197=0 if q197==.
replace q198=0 if q198==.
replace q199=0 if q199==.
replace q1910=0 if q1910==.
egen active_saving_nozero=rowtotal(q191 q192 q193 q194 q195 q196 q197 q198 q199 q1910)
// Generate active saving if person saves using any one means 
gen active_saving=1 if active_saving_nozero>0
replace active_saving=0 if active_saving==.
drop active_saving_nozero
label variable active_saving "Active Saving"

// Avoid Borrowing to make ends meet
egen finance_total=rowtotal(q411 q412 q413 q414 q415 q416 q417 q418 q419 q4110 q4111 q4112 q4113 q4114 q4115)
replace q41=0 if finance_total==0 & q41==.
replace q41=1 if finance_total>=0 & q41==.
drop finance_total
gen avoid_borrow=1 if q416==0 | q417==0 | q418==0 | q419 ==0 | q4110==0 | q4111==0 | q4112==0 | q4113==0 | q4114==0 | q4115 ==0 
replace avoid_borrow=0 if avoid_borrow==.
label variable avoid_borrow "Avoid Borrowing to make ends meet"

// Choosing Product (Score=1 if Atleast try ot compare across products while choosing product, Score=2 if uses financial advisor to choose products)
replace q381=0 if q371==0 
replace q382=0 if q372==0
replace q383=0 if q373==0
replace q384=0 if q374==0
replace q385=0 if q375==0
replace q386=0 if q376==0
replace q387=0 if q377==0
replace q388=0 if q378==0
replace q389=0 if q379==0
replace q3810=0 if q3710==0
replace q3811=0 if q3711==0
replace q3812=0 if q3712==0
replace q3813=0 if q3713==0
replace q3814=0 if q3714==0
replace q3815=0 if q3715==0
replace q3816=0 if q3716==0
replace q3817=0 if q3717==0
replace q3818=0 if q3718==0
replace q3819=0 if q3719==0
replace q3820=0 if q3720==0
replace q3821=0 if q3721==0
replace q3822=0 if q3722==0
replace q3823=0 if q3723==0
replace q3824=0 if q3724==0
//Generate compare product to True if compares product while choosing 
gen compare_product=1 if q381>=2 |  q382>=2|   q383>=2|   q384>=2|   q385>=2|   q386>=2|   q387>=2|   q388>=2|   q389>=2|   q3810>=2|   q3811>=2|   q3812>=2|   q3813>=2|   q3814>=2|   q3815>=2|   q3816>=2|   q3817>=2|   q3818>=2|   q3819>=2|   q3820>=2|   q3821>=2|   q3822>=2|   q3823>=2|   q3824>=2
replace compare_product=0 if compare_product==.



// If uses independent advise or product knowledge to choose product score=2 on choosing products
gen expert_use=1 if q395==1 | q396==1
replace expert_use=0 if expert_use==.
replace compare_product=2 if compare_product==1 & expert_use==1
drop expert_use
label variable compare_product "Choosing Product"


// Keep Watch on financial affairs
gen watch_financial_affairs = 1 if inlist(q33, 1, 2)
replace watch_financial_affairs = 0 if inlist(q33, 3, 4,5)
//* to comment
//replace watch_financial_affairs = 0 if watch_financial_affairs==.
label variable watch_financial_affairs " Keep watch on financial affairs"

// Financial Goals
gen financial_goal = 1 if inlist(q34, 1, 2)
replace financial_goal = 0 if inlist(q34, 3, 4,5)
//* to comment
//replace financial_goal = 0 if financial_goal==.

label  variable financial_goal "Financial Goals"

//Making considered Purchases
gen considered_purchases = 1 if inlist(q28, 1, 2)
replace considered_purchases = 0 if inlist(q28, 3, 4,5)
//* to comment
//replace considered_purchases = 0 if considered_purchases==.


label  variable considered_purchases "Considered Purchases"
//Paying Bills on time
gen pay_timely = 1 if inlist(q31, 1, 2)
replace pay_timely = 0 if inlist(q31, 3, 4,5)
//* to comment
//replace pay_timely = 0 if pay_timely==.

label  variable pay_timely "Timely Payment of Bills"
// Final Financial Behavior Score (0-9)
egen fbehavior=rowtotal( budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely )

// Financial Attidude score
//Save Attitude
gen save_attitude= q29

// uncomment
//replace save_attitude=0 if save_attitude==.

// Money attitudegen
gen money_attitude = q35
// uncomment
//replace money_attitude=0 if money_attitude==.


// Longter saving attitude
gen longterm_save_attitude= q30
// uncomment
//replace longterm_save_attitude=0 if longterm_save_attitude==.



egen fattitude=rowtotal(save_attitude money_attitude longterm_save_attitude)
replace fattitude=(fattitude/3)*(4/5)

egen fliteracy=rowtotal(fknowledge fbehavior fattitude)

// Financial Inclusion Indicator
gen saving_ac=1 if q371==1
replace saving_ac=0 if saving_ac==.
gen curr_ac=1 if q372==1
replace curr_ac=0 if curr_ac==.
gen fixed_ac=1 if q373==1
replace fixed_ac=0 if fixed_ac==.
gen bank_loan=1 if q374==1
replace bank_loan=0 if bank_loan==.
gen mob_banking=1 if q375==1
replace mob_banking=0 if mob_banking==.
gen int_banking=1 if q376==1
replace int_banking=0 if int_banking==.
gen card=1 if q377==1
replace card=0 if card==.
gen micro_saving_ac=1 if q378==1
replace micro_saving_ac=0 if micro_saving_ac==.
gen micro_loan_ac=1 if q379==1
replace micro_loan_ac=0 if micro_loan_ac==.
gen loan_no_coll=1 if q3710==1
replace loan_no_coll=0 if loan_no_coll==.
gen coop_saving_ac=1 if q3711==1
replace coop_saving_ac=0 if coop_saving_ac==.
gen coop_loan_ac=1 if q3712==1
replace coop_loan_ac=0 if coop_loan_ac==.
gen psp_ac=1 if q3713==1
replace psp_ac=0 if psp_ac==.
gen collective_saving=1 if q3714==1
replace collective_saving=0 if collective_saving==.
gen collective_loan=1 if q3715==1
replace collective_loan=0 if collective_loan==.
gen life_insurance=1 if q3716==1
replace life_insurance=0 if life_insurance==.
gen nonlife_insuarance=1 if q3717==1
replace nonlife_insuarance=0 if nonlife_insuarance==.
gen pension_ac=1 if q3718==1
replace pension_ac=0 if pension_ac==.
gen cit_ac=1 if q3719==1
replace cit_ac=0 if cit_ac==.
gen share=1 if q3720==1
replace share=0 if share==.
gen debenture_bond=1 if q3721==1
replace debenture_bond=0 if debenture_bond==.
gen intl_rem=1 if q3722==1
replace intl_rem=0 if intl_rem==.
gen dom_rem=1 if q3723==1
replace dom_rem=0 if dom_rem==.
gen gov_conc_loan=1 if q3724==1
replace gov_conc_loan=0 if gov_conc_loan==.

gen payment_prod=1 if mob_banking==1|   int_banking==1|   card==1|   saving_ac==1|   curr_ac==1| psp_ac==1
replace payment_prod=0 if payment_prod==.

gen access_saving_inv_ret=1 if saving_ac==1| curr_ac==1| fixed_ac==1| micro_saving_ac==1| coop_saving_ac==1 | collective_saving==1|  pension_ac==1|   cit_ac==1|   share==1|   debenture_bond==1
replace access_saving_inv_ret=0 if access_saving==.

gen hold_ins=1 if life_insurance==1|   nonlife_insuarance==1
replace hold_ins=0 if hold_ins==.

gen credit_prod=1 if bank_loan==1|   micro_loan_ac==1|   loan_no_coll==1|   coop_loan_ac==1|   collective_loan==1
replace credit_prod=0 if credit_prod==.

//Number of Product Awareness
egen product_aware=rowtotal(q361 q362 q363 q364 q365 q366 q367 q368 q369 q3610 q3611 q3612 q3613 q3614 q3615 q3616 q3617 q3618 q3619 q3620 q3621 q3622 q3623 q3624)
gen aware_5_prod=1 if product_aware>=5
replace aware_5_prod=0 if aware_5_prod==.
//Relying on Freind and Family
gen rely_fnf=1 if q192>0 | q415==1
replace rely_fnf=0 if rely_fnf==.

//Minimum Financial Knowledge
gen min_fk=1 if fknowledge>=5
replace min_fk=0 if min_fk==.

//Minimum Financial Behavior
gen min_fb=1 if fbehavior>=6
replace min_fb=0 if min_fb==.

//Minimum Financial Attitude
gen min_fa=1 if fbehavior>=2.4
replace min_fa=0 if min_fa==.

//Minimum Financial Literacy
gen min_fl=1 if min_fk==1 & min_fb==1 & min_fa==1
replace min_fl=0 if min_fl==.


merge m:1 q0 q3 using loc_det_gen
order province district palika wardno samplesize locallevel_id dis_loc_type_id district_dbase local_level_type pop_dltype pop_dltype_male pop_dltype_female pop, before( q3)

drop _merge

gen data_id=_n

order data_id

preserve

collapse (count) samplesize=q0 (mean) population=pop division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf min_fk min_fb min_fa min_fl, by(province district dis_loc_type_id district_dbase local_level_type q3)

export excel using "FLI.xls", sheet("dltype") firstrow(variables) replace

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf min_fk min_fb min_fa min_fl [fw=population], by(province district  district_dbase q3)

export excel using "FLI.xls", sheet("district_gender") firstrow(variables) 


// Province All

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf min_fk min_fb min_fa min_fl [fw=population], by(province q3)

export excel using "FLI.xls", sheet("province_gender") firstrow(variables) 

gen national="Nepal"

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf min_fk min_fb min_fa min_fl [fw=population], by(national q3)

export excel using "FLI.xls", sheet("national_gender") firstrow(variables) 

// Combined Upto Province
// District All
restore 
preserve

collapse (count) samplesize=q0 (mean) population=pop division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl, by(province district dis_loc_type_id district_dbase local_level_type q3)

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl [fw=population], by(province district  district_dbase)

export excel using "FLI.xls", sheet("district") firstrow(variables) 


// Province All

restore 
preserve

collapse (count) samplesize=q0 (mean) population=pop division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl, by(province district dis_loc_type_id district_dbase local_level_type q3)

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl [fw=population], by(province district  district_dbase q3)

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl [fw=population], by(province q3)

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl [fw=population], by(province)

export excel using "FLI.xls", sheet("province_all") firstrow(variables) 

// Nepal All

restore 
preserve
gen national="Nepal"

collapse (count) samplesize=q0 (mean) population=pop division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl, by(national province district dis_loc_type_id district_dbase local_level_type q3)

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl [fw=population], by(national province district  district_dbase q3)

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl [fw=population], by(national province q3)

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl [fw=population], by(national q3)

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl [fw=population], by(national)

export excel using "FLI.xls", sheet("national") firstrow(variables) 

// Local Level Type
restore
preserve

collapse (count) samplesize=q0 (mean) population=pop division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl, by(province district dis_loc_type_id district_dbase local_level_type q3)

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl [fw=population], by(province district  district_dbase local_level_type q3)

collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl [fw=population], by(local_level_type q3)

export excel using "FLI.xls", sheet("local_level_gender") firstrow(variables) 
collapse (rawsum) samplesize population (mean)  division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl [fw=population], by(local_level_type)

export excel using "FLI.xls", sheet("local_level") firstrow(variables) 



// Age 
restore
preserve 
collapse (count) samplesize=q0 (mean) population=pop_dltype_female division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl, by(q4)

export excel using "FLI.xls", sheet("age") firstrow(variables) 

restore
// Maritial Status 

preserve 
collapse (count) samplesize=q0 (mean) population=pop_dltype_female division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl, by(q6)

export excel using "FLI.xls", sheet("maritial_stat") firstrow(variables) 

restore
preserve 
// Family Size
replace q71=0 if q71==.
replace q72=0 if q72==.
replace q7=q71+q72

collapse (count) samplesize=q0 (mean) population=pop_dltype_female division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl, by(q7)

export excel using "FLI.xls", sheet("fam_size") firstrow(variables) 

restore
preserve 
// Education Level

collapse (count) samplesize=q0 (mean) population=pop_dltype_female division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf min_fk min_fb min_fa min_fl, by(q8)

export excel using "FLI.xls", sheet("edu_level") firstrow(variables) 

restore
preserve 
// Employment Status

collapse (count) samplesize=q0 (mean) population=pop_dltype_female division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf min_fk min_fb min_fa min_fl, by(q9)

export excel using "FLI.xls", sheet("emp_stat") firstrow(variables) 

restore
preserve 
// Employer Formal/Informal

collapse (count) samplesize=q0 (mean) population=pop_dltype_female division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf min_fk min_fb min_fa min_fl, by(q10)

export excel using "FLI.xls", sheet("sector_formal") firstrow(variables) 

restore
preserve 
// Occupational Type

collapse (count) samplesize=q0 (mean) population=pop_dltype_female division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf min_fk min_fb min_fa min_fl, by(q11)

export excel using "FLI.xls", sheet("occupation") firstrow(variables) 

restore
preserve 
// Industry

collapse (count) samplesize=q0 (mean) population=pop_dltype_female division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf min_fk min_fb min_fa min_fl, by(q12)

export excel using "FLI.xls", sheet("industry") firstrow(variables) 

restore
preserve 
// Income

collapse (count) samplesize=q0 (mean) population=pop_dltype_female division inf_pp con_int simp_int comp_int risk_return impct_inf risk_div budgeting active_saving avoid_borrow compare_product watch_financial_affairs financial_goal considered_purchases pay_timely save_attitude money_attitude longterm_save_attitude fknowledge fbehavior fattitude fliteracy saving_ac  curr_ac  fixed_ac  bank_loan  mob_banking  int_banking  card  micro_saving_ac  micro_loan_ac  loan_no_coll  coop_saving_ac  coop_loan_ac  psp_ac  collective_saving  collective_loan  life_insurance  nonlife_insuarance  pension_ac  cit_ac  share  debenture_bond  intl_rem  dom_rem  gov_conc_loan payment_prod access_saving_inv_ret hold_ins credit_prod aware_5_prod rely_fnf  min_fk min_fb min_fa min_fl, by(q15)

export excel using "FLI.xls", sheet("income") firstrow(variables) 



// Use district database+ use spmap+ requires district coordinate database to work
// Needs modification in directory for coordinates too

//spmap fknowledge using "E:\FLI\Districts\npcoord.dta", id(id) fcolor(BuYlRd) label(xcoord(x_cc) ycoord(y_cc) label(district) length(15) size(*0.33 .) ) clmethod(custom) clbreaks(1.4 2.8 3.5 4.2 7) legtitle("Financial Knowledge Score (0-7)") title("Financial Knowledge by District")

//spmap fbehavior using "E:\FLI\Districts\npcoord.dta", id(id) fcolor(BuYlRd) label(xcoord(x_cc) ycoord(y_cc) label(district) length(15) size(*0.33 .) ) clmethod(custom) clbreaks(1.8 3.6 4.5 5.4 9) legtitle("Financial Behavior Score (0-9)") title("Financial Behavior by District")

//spmap fattitude using "E:\FLI\Districts\npcoord.dta", id(id) fcolor(BuYlRd) label(xcoord(x_cc) ycoord(y_cc) label(district) length(15) size(*0.33 .) ) clmethod(custom) clbreaks(6 8 10 12 14 20) legtitle("Financial Literacy Score (0-20)") title("Financial Attitude by District")

//spmap fliteracy using "E:\FLI\Districts\npcoord.dta", id(id) fcolor(BuYlRd) label(xcoord(x_cc) ycoord(y_cc) label(district) length(15) size(*0.33 .) ) clmethod(custom) clbreaks(6 8 10 12 14 20) legtitle("Financial Literacy Score (0-20)") title("Financial Literacy by District")